@@ -29,5 +29,11 @@ test_that("lookup_coords returns coords data", {
     expect_named(x)
     expect_true("box" %in% names(x))
   }
+  e <- names(Sys.getenv())
+  g <- grep("google", e, ignore.case = TRUE, value = TRUE)
+  ng <- as.list(rep("", length(g)))
+  names(ng) <- g
+  do.call(Sys.setenv, ng)
+  expect_error(lookup_coords("London, UK"))
 })
 
