@@ -15,10 +15,10 @@ test_that("lookup_statuses returns users data", {
   expect_true("status_id" %in% names(x))
   expect_equal(nrow(x), n)
   expect_gt(ncol(x), 15)
-  expect_true("users" %in% names(attributes(x)))
-  expect_true(is.data.frame(attr(x, "users")))
-  expect_true(is.data.frame(users_data(x)))
-  expect_gt(nrow(users_data(x)), 0)
-  expect_gt(ncol(users_data(x)), 15)
-  expect_named(users_data(x))
+  expect_true(all(c("friends_count", "statuses_count") %in% names(x)))
+  #expect_true(is.data.frame(attr(x, "users")))
+  #expect_true(is.data.frame(users_data(x)))
+  #expect_gt(nrow(users_data(x)), 0)
+  #expect_gt(ncol(users_data(x)), 15)
+  #expect_named(users_data(x))
 })
